@@ -1,8 +1,9 @@
 import xplainable_client as xpc
 
+print("Connecting")
 client = xpc.Client(
     api_key="55a506e7-07cd-4bc5-9a2c-5cb6d27b1c05",
-    hostname="https://xplainable-api-uat-45xyq.ondigitalocean.app"
+    hostname="https://xplainable-api-uat-itdcj.ondigitalocean.app/"
 )
 
 print(client)
