@@ -9,7 +9,7 @@ from .utils.metrics import evaluate_classification, evaluate_regression
 
 class Models(Client_Cog):
 
-    def create_model(self, model_name: str, model_description: str, model, x: pd.DataFrame, y: pd.Series):
+    def create_model(self, model, model_name: str, model_description: str, x: pd.DataFrame, y: pd.Series):
         """ Creates a new model if the model does not already exist.
 
         Args:
@@ -26,66 +26,27 @@ class Models(Client_Cog):
         Raises:
             Exception: If the model creation fails.
         """
-        model_id = self.create_model_id(model, model_name, model_description)
-        try:
-            version_id = self.create_model_version(model, model_id, x, y)
-        except Exception as e:
-            self.delete_model(model_id)
-            raise e
-        return model_id, version_id
-    
-    def create_model_id(
-            self, model, model_name: str, model_description: str) -> str:
-        """ Creates a new model and returns the model id.
-        Args:
-            model_name (str): The name of the model
-            model_description (str): The description of the model
-            model (XClassifier | XRegressor): The model to create.
-        Returns:
-            int: The model id
-        """
+
         model_type, target = self._detect_model_type(model)
-        payoad = {
-            "model_name": model_name,
-            "model_description": model_description,
-            "model_type": model_type,
+        payload = {
+            "name": model_name,
+            "description": model_description,
+            "type": model_type,
             "target_name": target,
             "algorithm": model.__class__.__name__
         }
 
-        response = self.session._session.post(
-            url=f'{self.session.hostname}/v1/{self.session._ext}/create-model',
-            json=payoad
+        partition_on = model.partition_on if 'Partitioned' in model.__class__.__name__ else None
+        payload.update(
+            {
+                "partition_on": partition_on,
+                "versions": {
+                    "xplainable_version": self.session.xplainable_version,
+                    "python_version": self.session.python_version
+                },
+                "partitions": []
+            }
         )
-        model_id = self.session.get_response_content(response)
-
-        return model_id
-
-    
-    #TODO: Refactor this based on notion instructions.
-    def create_model_version(self, model, model_id: str, x: pd.DataFrame, y: pd.Series) -> str:
-        """ Creates a new model version and returns the version id.
-        Args:
-            model_id (int): The model id
-            partition_on (str): The partition column name
-            ruleset (dict | str): The feeature ruleset
-            health_info (dict): Feature health information
-            versions (dict): Versions of current environment
-        Returns:
-            int: The model version id
-        """
-        # Get current versions
-        versions = {
-                "xplainable_version": self.session.xplainable_version,
-                "python_version": self.session.python_version
-            }
-        partition_on = model.partition_on if 'Partitioned' in \
-            model.__class__.__name__ else None
-        payload = {
-            "partition_on": partition_on,
-            "versions": versions,
-            "partitions": []
-            }
         partitioned_models = ['PartitionedClassifier', 'PartitionedRegressor']
         independent_models = ['XClassifier', 'XRegressor']
         # get all partitions
@@ -104,11 +65,79 @@ class Models(Client_Cog):
             pdata = self._get_partition_data(model, '__dataset__', x, y)
             payload['partitions'].append(pdata)
 
+        """
+        response = self.session._session.post(
+            url=f'{self.session.hostname}/v1/{self.session._ext}/create-model',
+            json=payoad
+        )
+        model_id = self.session.get_response_content(response)
+        """
+
         # Create a new version and fetch id
-        url = f'{self.session.hostname}/v1/{self.session._ext}/models/{model_id}/add-version'
+        url = f'{self.session.hostname}/client/models/create'
         response = self.session._session.post(url=url, json=force_json_compliant(payload))
-        version_id = self.session.get_response_content(response)
-        return version_id
+        content = self.session.get_response_content(response)
+
+        return content
+
+    def add_version(self, model, x: pd.DataFrame, y: pd.Series):
+        """
+        Creates a new model if the model does not already exist.
+
+        Args:
+            model (XClassifier | XRegressor): The model to create
+            x (pd.DataFrame): The feature matrix
+            y (pd.Series): The target variable
+
+        Returns:
+            str: The model id
+            str: The version id
+
+        Raises:
+            Exception: If the model creation fails.
+        """
+
+        partition_on = model.partition_on if 'Partitioned' in model.__class__.__name__ else None
+        payload = {
+            "partition_on": partition_on,
+            "versions": {
+                "xplainable_version": self.session.xplainable_version,
+                "python_version": self.session.python_version
+            },
+            "partitions": []
+        }
+        partitioned_models = ['PartitionedClassifier', 'PartitionedRegressor']
+        independent_models = ['XClassifier', 'XRegressor']
+        # get all partitions
+        if model.__class__.__name__ in partitioned_models:
+            for p, m in model.partitions.items():
+                if p == '__dataset__':
+                    part_x = x
+                    part_y = y
+                else:
+                    part_x = x[x[partition_on].astype(str) == str(p)]
+                    part_y = y[y.index.isin(part_x.index)]
+                pdata = model._get_partition_data(m, p, part_x, part_y)
+                payload['partitions'].append(pdata)
+
+        elif model.__class__.__name__ in independent_models:
+            pdata = self._get_partition_data(model, '__dataset__', x, y)
+            payload['partitions'].append(pdata)
+
+        """
+        response = self.session._session.post(
+            url=f'{self.session.hostname}/v1/{self.session._ext}/create-model',
+            json=payoad
+        )
+        model_id = self.session.get_response_content(response)
+        """
+
+        # Create a new version and fetch id
+        url = f'{self.session.hostname}/client/models/add-version'
+        response = self.session._session.post(url=url, json=force_json_compliant(payload))
+        content = self.session.get_response_content(response)
+
+        return content
 
     def _get_partition_data(
             self, model, partition_name: str, x: pd.DataFrame,
@@ -202,7 +231,6 @@ class Models(Client_Cog):
             data["health_info"] = json.dumps(results, cls=NpEncoder)
 
         return data
-        
 
     def list_models(self) -> list:
         """ Lists all models of the active user's team.
@@ -222,7 +250,6 @@ class Models(Client_Cog):
         [i.pop('contributors') for i in data]
 
         return data
-    
 
     def __get_model__(self, model_id: int, version_id: int):
         """ Gets a model with a specific version.
@@ -258,7 +285,6 @@ class Models(Client_Cog):
                 - model.target (str): The model target. 
         """
 
-
         if 'Partitioned' in model.__class__.__name__:
             model = model.partitions['__dataset__']
         cls_name = model.__class__.__name__
